pub struct DrainHost {
pub timeout: Duration,
pub max_in_flight: usize,
pub host_mesh_name: Option<Name>,
pub ack: PortRef<()>,
}Expand description
Drain user procs on this host but keep the host, service proc, and networking alive. Used during mesh stop/shutdown so that forwarder flushes can still reach remote hosts.
If host_mesh_name is Some, only procs belonging to that mesh
are stopped (selective drain). If None, all procs are
terminated (full drain).
Fields
timeout: Durationmax_in_flight: usizehost_mesh_name: Option<Name>ack: PortRef<()>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for DrainHost
impl<'de> Deserialize<'de> for DrainHost
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Named for DrainHost
impl Named for DrainHost
Sourcefn typename() -> &'static str
fn typename() -> &'static str
The globally unique type name for the type.
This should typically be the fully qualified Rust name of the type.
Sourcefn typehash() -> u64
fn typehash() -> u64
A globally unique hash for this type.
TODO: actually enforce perfect hashing
Sourcefn typeid() -> TypeId
fn typeid() -> TypeId
The TypeId for this type. TypeIds are unique only within a binary,
and should not be used for global identification.
Sourcefn port() -> u64
fn port() -> u64
The globally unique port for this type. Typed ports are in the range
of 1<<63..1<<64-1.
impl Accepts<DrainHost> for HostAgent
impl RemoteHandles<DrainHost> for HostAgent